@@ -4,7 +4,7 @@
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2022 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_GNUTLS_X509_H__
 #define __XMLSEC_GNUTLS_X509_H__
@@ -54,7 +54,6 @@ XMLSEC_CRYPTO_EXPORT gnutls_x509_crl_t  xmlSecGnuTLSKeyDataX509GetCrl
                                                                                  xmlSecSize pos);
 XMLSEC_CRYPTO_EXPORT xmlSecSize         xmlSecGnuTLSKeyDataX509GetCrlsSize      (xmlSecKeyDataPtr data);
 
-
 XMLSEC_CRYPTO_EXPORT xmlSecKeyDataPtr   xmlSecGnuTLSX509CertGetKey              (gnutls_x509_crt_t cert);
 
 /**************************************************************************
@@ -84,19 +83,7 @@ XMLSEC_CRYPTO_EXPORT xmlSecKeyDataId    xmlSecGnuTLSKeyDataRawX509CertGetKlass
 #define xmlSecGnuTLSX509StoreId \
         xmlSecGnuTLSX509StoreGetKlass()
 XMLSEC_CRYPTO_EXPORT xmlSecKeyDataStoreId xmlSecGnuTLSX509StoreGetKlass (void);
-XMLSEC_CRYPTO_EXPORT gnutls_x509_crt_t  xmlSecGnuTLSX509StoreFindCert   (const xmlSecKeyDataStorePtr store,
-                                                                         const xmlChar *subjectName,
-                                                                         const xmlChar *issuerName,
-                                                                         const xmlChar *issuerSerial,
-                                                                         const xmlChar *ski,
-                                                                         const xmlSecKeyInfoCtx* keyInfoCtx);
-XMLSEC_CRYPTO_EXPORT gnutls_x509_crt_t xmlSecGnuTLSX509StoreFindCert_ex(const xmlSecKeyDataStorePtr store,
-                                                                         const xmlChar *subjectName,
-                                                                         const xmlChar *issuerName,
-                                                                         const xmlChar *issuerSerial,
-                                                                         const xmlSecByte * ski,
-                                                                         xmlSecSize skiSize,
-                                                                         const xmlSecKeyInfoCtx* keyInfoCtx);
+
 XMLSEC_CRYPTO_EXPORT gnutls_x509_crt_t  xmlSecGnuTLSX509StoreVerify     (xmlSecKeyDataStorePtr store,
                                                                          xmlSecPtrListPtr certs,
                                                                          xmlSecPtrListPtr crls,
@@ -105,7 +92,8 @@ XMLSEC_CRYPTO_EXPORT int                xmlSecGnuTLSX509StoreAdoptCert  (xmlSecK
                                                                          gnutls_x509_crt_t cert,
                                                                          xmlSecKeyDataType type);
 
-
+XMLSEC_CRYPTO_EXPORT int                xmlSecGnuTLSX509StoreAdoptCrl  (xmlSecKeyDataStorePtr store,
+                                                                         gnutls_x509_crl_t crl);
 
 
 #ifdef __cplusplus
