@@ -1,13 +1,13 @@
 /*
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
- * <dsig:KeyInfo> element processing
+ * &lt;dsig:KeyInfo/&gt; element processing
  * (http://www.w3.org/TR/xmlSec-core/#sec-KeyInfo:
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2002-2016 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_KEYINFO_H__
 #define __XMLSEC_KEYINFO_H__
@@ -16,6 +16,7 @@
 
 #include <libxml/tree.h>
 
+#include <xmlsec/exports.h>
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/list.h>
 #include <xmlsec/keysdata.h>
@@ -154,6 +155,23 @@ typedef enum {
  */
 #define XMLSEC_KEYINFO_FLAGS_X509DATA_SKIP_STRICT_CHECKS        0x00004000
 
+
+/**
+ * XMLSEC_KEYINFO_FLAGS_LAX_KEY_SEARCH:
+ *
+ * If the flag is set then we'll try to find any key that matches requirements
+ * (e.g. *any* RSA public key). In the default strict key search mode, only keys
+ * referenced in &lt;dsig:KeyInfo/&gt; (e.g. by KeyName value) are used.
+ */
+#define XMLSEC_KEYINFO_FLAGS_LAX_KEY_SEARCH                     0x00008000
+
+/**
+ * XMLSEC_KEYINFO_FLAGS_X509DATA_SKIP_TIME_CHECKS:
+ *
+ * If the flag is set then we'll skip time checks of certs and CRLs
+ */
+#define XMLSEC_KEYINFO_FLAGS_X509DATA_SKIP_TIME_CHECKS          0x00010000
+
 /**
  * xmlSecKeyInfoCtx:
  * @userData:           the pointer to user data (xmlsec and xmlsec-crypto
@@ -168,12 +186,17 @@ typedef enum {
  * @retrievalMethodCtx: the transforms context for <dsig:RetrievalMethod />
  *                      element processing.
  * @maxRetrievalMethodLevel: the max recursion level when processing
- *                      <dsig:RetrievalMethod /> element; default level is 1
+ *                     &lt;dsig:RetrievalMethod/&gt; element; default level is 1
  *                      (see also @curRetrievalMethodLevel).
+ * @keyInfoReferenceCtx: the transforms context for&lt;dsig11:KeyInfoReference/&gt;
+ *                      element processing.
+ * @maxKeyInfoReferenceLevel: the max recursion level when processing
+ *                     &lt;dsig11:KeyInfoReference/&gt; element; default level is 1
+ *                      (see also @curKeyInfoReferenceLevel).
  * @encCtx:             the encryption context for <dsig:EncryptedKey /> element
  *                      processing.
  * @maxEncryptedKeyLevel: the max recursion level when processing
- *                      <enc:EncryptedKey /> element; default level is 1
+ *                     &lt;enc:EncryptedKey/&gt; element; default level is 1
  *                      (see @curEncryptedKeyLevel).
  * @certsVerificationTime: the time to use for X509 certificates verification
  *                      ("not valid before" and "not valid after" checks);
@@ -182,10 +205,13 @@ typedef enum {
  *                      clock "now".
  * @certsVerificationDepth: the max certifications chain length (default is 9).
  * @pgpReserved:        reserved for PGP.
- * @curRetrievalMethodLevel: the current <dsig:RetrievalMethod /> element
+ * @curRetrievalMethodLevel: the current&lt;dsig:RetrievalMethod/&gt; element
  *                      processing level (see @maxRetrievalMethodLevel).
- * @curEncryptedKeyLevel: the current <enc:EncryptedKey /> element
+ * @curKeyInfoReferenceLevel: the current&lt;dsig11:KeyInfoReference/&gt; element
+ *                      processing level (see @maxKeyInfoReferenceLevel).
+ * @curEncryptedKeyLevel: the current&lt;enc:EncryptedKey/&gt; or&lt;enc11:DerivedKey/&gt; element
  *                      processing level (see @maxEncryptedKeyLevel).
+ * @operation:          the transform operation for this key info.
  * @keyReq:             the current key requirements.
  * @reserved0:          reserved for the future.
  * @reserved1:          reserved for the future.
@@ -205,8 +231,12 @@ struct _xmlSecKeyInfoCtx {
     xmlSecTransformCtx                  retrievalMethodCtx;
     int                                 maxRetrievalMethodLevel;
 
+    /* KeyInfoReference */
+    xmlSecTransformCtx                  keyInfoReferenceCtx;
+    int                                 maxKeyInfoReferenceLevel;
+
 #ifndef XMLSEC_NO_XMLENC
-    /* EncryptedKey */
+    /* EncryptedKey or DerivedKey */
     xmlSecEncCtxPtr                     encCtx;
     int                                 maxEncryptedKeyLevel;
 #endif /* XMLSEC_NO_XMLENC */
@@ -222,7 +252,9 @@ struct _xmlSecKeyInfoCtx {
 
     /* internal data */
     int                                 curRetrievalMethodLevel;
+    int                                 curKeyInfoReferenceLevel;
     int                                 curEncryptedKeyLevel;
+    xmlSecTransformOperation            operation;
     xmlSecKeyReq                        keyReq;
 
     /* for the future */
@@ -246,7 +278,7 @@ XMLSEC_EXPORT void                      xmlSecKeyInfoCtxDebugXmlDump    (xmlSecK
 /**
  * xmlSecKeyDataNameId
  *
- * The <dsig:KeyName> processing class.
+ * The&lt;dsig:KeyName/&gt; processing class.
  */
 #define xmlSecKeyDataNameId             xmlSecKeyDataNameGetKlass()
 XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataNameGetKlass       (void);
@@ -254,7 +286,7 @@ XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataNameGetKlass       (void);
 /**
  * xmlSecKeyDataValueId
  *
- * The <dsig:KeyValue> processing class.
+ * The&lt;dsig:KeyValue/&gt; processing class.
  */
 #define xmlSecKeyDataValueId            xmlSecKeyDataValueGetKlass()
 XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataValueGetKlass      (void);
@@ -262,19 +294,45 @@ XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataValueGetKlass      (void);
 /**
  * xmlSecKeyDataRetrievalMethodId
  *
- * The <dsig:RetrievalMethod> processing class.
+ * The&lt;dsig:RetrievalMethod/&gt; processing class.
  */
 #define xmlSecKeyDataRetrievalMethodId  xmlSecKeyDataRetrievalMethodGetKlass()
 XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataRetrievalMethodGetKlass(void);
 
+/**
+ * xmlSecKeyDataKeyInfoReferenceId
+ *
+ * The&lt;dsig11:KeyInfoReference/&gt; processing class.
+ */
+#define xmlSecKeyDataKeyInfoReferenceId xmlSecKeyDataKeyInfoReferenceGetKlass()
+XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataKeyInfoReferenceGetKlass(void);
+
 #ifndef XMLSEC_NO_XMLENC
 /**
  * xmlSecKeyDataEncryptedKeyId
  *
- * The <enc:EncryptedKey> processing class.
+ * The&lt;enc:EncryptedKey/&gt; element processing class.
  */
 #define xmlSecKeyDataEncryptedKeyId     xmlSecKeyDataEncryptedKeyGetKlass()
 XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataEncryptedKeyGetKlass(void);
+
+/**
+ * xmlSecKeyDataAgreementMethodId
+ *
+ * The&lt;enc:AgreementMethod/&gt; processing class.
+ */
+#define xmlSecKeyDataAgreementMethodId  xmlSecKeyDataAgreementMethodGetKlass()
+XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataAgreementMethodGetKlass(void);
+
+/**
+ * xmlSecKeyDataDerivedKeyId
+ *
+ * The&lt;enc11:DerivedKey/&gt; processing class.
+ */
+#define xmlSecKeyDataDerivedKeyId       xmlSecKeyDataDerivedKeyGetKlass()
+XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataDerivedKeyGetKlass(void);
+
+
 #endif /* XMLSEC_NO_XMLENC */
 
 #ifdef __cplusplus
@@ -282,4 +340,3 @@ XMLSEC_EXPORT xmlSecKeyDataId           xmlSecKeyDataEncryptedKeyGetKlass(void);
 #endif /* __cplusplus */
 
 #endif /* __XMLSEC_KEYINFO_H__ */
-
